##
##  openldap.spec -- OpenPKG RPM Specification
##  Copyright (c) 2000-2003 Cable & Wireless Deutschland GmbH
##  Copyright (c) 2000-2003 The OpenPKG Project <http://www.openpkg.org/>
##  Copyright (c) 2000-2003 Ralf S. Engelschall <rse@engelschall.com>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         openldap
Summary:      Lightweight Directory Access Protocol (LDAP) Toolkit
URL:          http://www.openldap.org/
Vendor:       OpenLDAP Project
Packager:     The OpenPKG Project
Distribution: OpenPKG [BASE]
Group:        Database
License:      GPL
Version:      2.1.21
Release:      20030609

#   package options
%option       with_sasl no

#   list of sources
Source0:      ftp://ftp.openldap.org/pub/openldap/openldap-release/openldap-%{version}.tgz
Source1:      rc.openldap

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20020206, openssl, db >= 4.1.24, make, gcc
PreReq:       OpenPKG, openpkg >= 20020206
%if "%{with_sasl}" == "yes"
BuildPreReq:  sasl
PreReq:       sasl
%endif
AutoReq:      no
AutoReqProv:  no

%description
    OpenLDAP is an open source implementation of the Lightweight
    Directory Access Protocol. The suite includes: slapd: stand-alone
    LDAP server; slurpd:- stand-alone LDAP replication server; libraries
    implementing the LDAP protocol, and utilities, tools, and sample
    clients.

%prep
    %setup -q

%build
    #   make sure our Berkeley-DB is picked up first
    %{l_shtool} subst \
        -e 's;-ldb41;-ldb;g' \
        configure
%if "%{with_sasl}" == "yes"
    #   hard-code configure to use SASL2 library
    %{l_shtool} subst \
        -e '4s/.*/ac_cv_lib_sasl2_sasl_client_init=yes/' \
        configure
    cf="%{l_cppflags sasl}"
%else
    cf="%{l_cppflags}"
%endif
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="$cf" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --localstatedir=%{l_prefix}/var/openldap \
        --enable-ldbm \
        --with-ldbm-api=berkeley \
        --with-ldbm-module=static \
        --with-ldbm-type=btree \
%if "%{with_sasl}" == "yes"
        --with-cyrus-sasl \
        --enable-spasswd \
%else
        --without-cyrus-sasl \
        --disable-spasswd \
%endif
        --enable-slurpd \
        --disable-shared
    %{l_make} %{l_mflags}

%install
    rm -rf $RPM_BUILD_ROOT
    %{l_make} %{l_mflags} install DESTDIR="$RPM_BUILD_ROOT"
    rm -f $RPM_BUILD_ROOT%{l_prefix}/etc/openldap/*.default
    rm -f $RPM_BUILD_ROOT%{l_prefix}/etc/openldap/*/*.default
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/var/openldap
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 -e 's;@l_prefix@;%{l_prefix};g' \
        -e 's;@l_susr@;%{l_susr};g' \
        %{SOURCE rc.openldap} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/openldap/*.conf'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

